from setuptools import setup


setup (
    name='gsnip',
    version='0.1',
    description='Command line tool for gists',
    author='jongwony',
    author_email='lastone9182@gmail.com',
    scripts=['gsnip'],
    url='https://github.com/jongwony/gsnip',
)
